# Promus

Promus is a remote manager designed to create and manage Git
repositories. It does so by executing `git` and `unison` commands on
behalf of a user who has been given authorization via an ssh public
key.
